@@ -2,26 +2,16 @@ import logging
 from os import path
 import time
 
-try:
-    from nose.tools import eq_
-    from nose.plugins.skip import SkipTest
-    from nose.plugins.attrib import attr
+import pytest
 
-    def skip_test(reason='No reason given to skip_test'):
-        raise SkipTest(reason)
+def eq_(a, b):
+    assert a == b
 
-    mark_slow = attr('slow')
-except ImportError:
-    import pytest
+def skip_test(reason='No reason given to skip_test'):
+    pytest.skip(reason)
 
-    def eq_(a, b):
-        assert a == b
-
-    def skip_test(reason='No reason given to skip_test'):
-        pytest.skip(reason)
-
-    def mark_slow(f):
-        return f
+def mark_slow(f):
+    return f
 
 import _mssql
 import pymssql
@@ -38,23 +28,25 @@ cfgpath = path.join(cdir, 'tests.cfg')
 global_mssqlconn = None
 
 
-def mssqlconn():
+def mssqlconn(conn_properties=None):
     return _mssql.connect(
         server=config.server,
         user=config.user,
         password=config.password,
         database=config.database,
         port=config.port,
+        conn_properties=conn_properties
     )
 
 
-def pymssqlconn():
+def pymssqlconn(**kwargs):
     return pymssql.connect(
         server=config.server,
         user=config.user,
         password=config.password,
         database=config.database,
         port=config.port,
+        **kwargs
     )
 
 
@@ -194,15 +186,6 @@ class TableManager(object):
 
 class DBAPIBase(object):
 
-    def newconn(self):
-        self.conn = self.__class__.get_conn()
-
-    def __init__(self):
-        self.newconn()
-
-    def setUp(self):
-        self.conn.rollback()
-
     def execute(self, sql):
         cur = self.conn.cursor()
         cur.execute(sql)
@@ -221,12 +204,13 @@ class CursorBase(DBAPIBase):
     When psycopg comparison isn't needed anymore, this class can be moved to
     test_pymssql and used directly.
     """
-    def __init__(self):
-        DBAPIBase.__init__(self)
-        self.t1 = TableManager(self.conn, 'test', 'id int', 'name varchar(50)')
+    @classmethod
+    def setup_class(cls):
+        cls.newconn()
+        cls.t1 = TableManager(cls.conn, 'test', 'id int', 'name varchar(50)')
 
-    def setUp(self):
-        DBAPIBase.setUp(self)
+    def setup_method(self, method):
+        self.conn.rollback()
         self.t1.clear()
         self.execute("insert into test values (1, 'one')")
         self.execute("insert into test values (2, 'two')")
@@ -310,9 +294,28 @@ class CursorBase(DBAPIBase):
     def test_as_dict_no_column_name(self):
         cur = self.conn.cursor(as_dict=True)
         try:
+            # SQL Server >= 2008:
+            #
+            #   SELECT MAX(x), MIN(x) AS [MIN(x)]
+            #   FROM (VALUES (1), (2), (3))
+            #   AS foo(x)
+            #
+            # SQL Server = 2005 (remove when we drop suport for it):
+            #
+            #   SELECT MAX(x), MIN(x) AS [MIN(x)]
+            #   FROM (SELECT 1
+            #         UNION ALL
+            #         SELECT 2
+            #         UNION ALL
+            #         SELECT 3)
+            #   AS foo(x)
             cur.execute(
                 "SELECT MAX(x), MIN(x) AS [MIN(x)] "
-                "FROM (VALUES (1), (2), (3)) AS foo(x)")
+                "FROM (SELECT 1"
+                "      UNION ALL"
+                "      SELECT 2"
+                "      UNION ALL"
+                "      SELECT 3) AS foo(x)")
             assert False, "Didn't raise InterfaceError"
         except pymssql.ColumnsWithoutNamesError as exc:
             eq_(exc.columns_without_names, [0])
@@ -320,9 +323,28 @@ class CursorBase(DBAPIBase):
     def test_as_dict_no_column_name_2(self):
         cur = self.conn.cursor(as_dict=True)
         try:
+            # SQL Server >= 2008:
+            #
+            #   SELECT MAX(x), MAX(y) AS [MAX(y)], MIN(y)
+            #   FROM (VALUES (1, 2), (2, 3), (3, 4))
+            #   AS foo(x, y)
+            #
+            # SQL Server = 2005 (remove when we drop suport for it):
+            #
+            #   SELECT MAX(x), MAX(y) AS [MAX(y)], MIN(y)
+            #   FROM (SELECT (1, 2)
+            #         UNION ALL
+            #         SELECT (2, 3)
+            #         UNION ALL
+            #         SELECT (3, 4))
+            #   AS foo(x, y)
             cur.execute(
                 "SELECT MAX(x), MAX(y) AS [MAX(y)], MIN(y) "
-                "FROM (VALUES (1, 2), (2, 3), (3, 4)) AS foo(x, y)")
+                "FROM (SELECT 1, 2"
+                "      UNION ALL"
+                "      SELECT 2, 3"
+                "      UNION ALL"
+                "      SELECT 3, 4) AS foo(x, y)")
             assert False, "Didn't raise InterfaceError"
         except pymssql.ColumnsWithoutNamesError as exc:
             eq_(exc.columns_without_names, [0, 2])
